@@ -12,6 +12,13 @@ class Course:
     def __init__(self, name, term):
         self.name = name
 	self.term = term
+
+def isAllCaps(string){
+    for str in string:
+        if str.islower():
+           return False
+    return True
+}
    
 def getCoursesTaken(html):
     parser = ParseCappReport()
@@ -19,10 +26,11 @@ def getCoursesTaken(html):
     html_text = parser.data_stack
     courses = []
     for i in range(len(html_text)):
-        if ((html_text[i] == "Grd" or re.match(r"^((^[A-F](-|\+))|P|(NC)|(AP)|(Reg))$", html_text[i]))
-        and len(html_text[i+1])==4 and html_text[i+2].isdigit() and not html_text[i+6] in ("F", "NC", "U", "W")):
-	    name = html_text[i+1]+" "+html_text[i+2]
-            term = html_text[i+5]
+        if (len(html_text[i]) == 4 and isAllCaps(html_text[i]) and 
+            len(html_text[i+1]) == 4 and html_text[i+1].isdigit() and 
+            not html_text[i+5] in ("F", "NC", "U", "W")):
+	    name = html_text[i]+" "+html_text[i+1]
+            term = html_text[i+4]
             courses.append(Course(name, term))
     return courses
     
\ No newline at end of file
